#
# spec file for package carla
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __provides_exclude_from ^%{_libdir}/carla/jack/.*.so.0$

Name:           carla
Version:        2.0.0+git20190321.20cc5244
Release:        3.20
Summary:        An audio plugin host
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
ExclusiveArch:  x86_64
Url:            http://kxstudio.linuxaudio.org/Applications:Carla
Source:         Carla-%{version}.tar.xz
Patch1:         carla-systemlibs.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkg-config
BuildRequires:  python3-devel
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-rdflib
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbisenc)
# for extra native plugins
BuildRequires:  non-ntk-fluid
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(zlib)
# for plugin GUIs
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(x11)
# for extra samplers support
BuildRequires:  pkgconfig(fluidsynth)

Requires:       python3-base
Requires:       python3-qt5

%description
Carla is an audio plugin host, with support for many audio drivers
and plugin formats. It features automation of parameters via MIDI CC
and full OSC control. It currently supports LADSPA, DSSI, LV2, VST2/3
and AU plugin formats, plus GIG, SF2 and SFZ sounds banks.
It futher supports bridging Window plugins using Wine.

%package devel
Summary:        Header files to access Carla's API
Group:          Development/Libraries/C and C++
BuildRequires:  pkg-config

%description devel
This package contains header files needed when writing software using
Carla's several APIs.

%package vst
Summary:        CarlaRack and CarlaPatchbay VST plugins
Group:          Productivity/Multimedia/Sound/Utilities

%description vst
This package contanis Carla VST plugins, including CarlaPatchbayFX,
CarlaPatchbay, CarlaRackFX, and CarlaRack.

%prep
%setup -q -n Carla-%{version}
%patch1 -p1

%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"

# list build configuration, no need for optflags or -j
make features

# bulding with high -j numbers often results in build failures, thus we're disabling _smp_flags for now 
make \
%ifnarch %ix86 x86_64
	BASE_OPTS= \
%endif
	--trace

%install
make install DESTDIR=%{buildroot} PREFIX="%{_prefix}" LIBDIR="%{_libdir}"
# Move arch depended files (wrong installed)
mv %{buildroot}%{_datadir}/carla/resources/zynaddsubfx-ui %{buildroot}%{_libdir}/carla
ln -s %{_libdir}/carla/zynaddsubfx-ui %{buildroot}%{_datadir}/carla/resources/zynaddsubfx-ui
# flags
for file in carla carla-control carla-jack-multi carla-jack-single carla-patchbay carla-rack carla_app.py carla_backend.py carla_backend_qt.py carla_config.py carla_control.py carla_database.py carla_host.py carla_shared.py carla_skin.py carla_utils.py carla_widgets.py carla_settings.py externalui.py ladspa_rdf.py patchcanvas.py patchcanvas_theme.py resources_rc.py; do
	chmod +x "%{buildroot}%{_datadir}/carla/$file"
done
# SUSE specific
%if 0%{?suse_version}
 %suse_update_desktop_file -r carla AudioVideo Music
 %suse_update_desktop_file -r carla-control AudioVideo Music
 %fdupes -s %{buildroot}%{_datadir}
%endif

%files
%defattr(-,root,root)
%doc INSTALL.md README.md doc
%{_bindir}/*
%dir %{_libdir}/carla
%{_libdir}/carla/*
%dir %{_libdir}/lv2
%dir %{_libdir}/lv2/carla.lv2
%{_libdir}/lv2/carla.lv2/*
%dir %{_datadir}/carla
%{_datadir}/carla/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/mime/packages/carla.xml

%files vst
%defattr(-,root,root)
%dir %{_libdir}/vst
%dir %{_libdir}/vst/carla.vst
%{_libdir}/vst/carla.vst/*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/carla
%{_includedir}/carla/*
%{_libdir}/pkgconfig/*

%changelog
* Tue Apr 30 2019 Edgar Aichinger <edogawa@aon.at>
- update to 2.0.0
* Mon Apr  1 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the Qt4 support. Qt4 will be removed from factory soon.
* Fri Mar 15 2019 Edgar Aichinger <edogawa@aon.at>
- Reverted %%description to previous state
* Mon Mar 11 2019 Edgar Aichinger <edogawa@aon.at>
- update to 2.0-RC4 (aka 1.9.14)
* Tue Nov 27 2018 Edgar Aichinger <edogawa@aon.at>
- spec: update application URL
- spec, package meta: update description
* Wed Nov 14 2018 Edgar Aichinger <edogawa@aon.at>
- spec: define provides-exclude for internal libjack.so.0
* Mon Nov 12 2018 Edgar Aichinger <edogawa@aon.at>
- updated carla-systemlibs.patch to current sources
- removed carla.libjack-soversion.patch (workaround for a past link problem, not needed anymore)
* Thu Nov  8 2018 Edgar Aichinger <edogawa@aon.at>
- updated to 2.0-RC2 (aka 1.9.12)
  * reenabled fluidsynth support
* Thu Sep 27 2018 Edgar Aichinger <edogawa@aon.at>
- updated to 2.0-RC1 (aka 1.9.11)
  * removed fluidsynth support temporarily (API changed)
  * removed carla.libjack-soversion.patch and carla-systemlibs.patch
    temporarily, will update these as needed in near future
* Thu Aug  9 2018 edogawa@aon.at
- fiddled with _service to include the git submodule ("native external plugins")
- major spec file cleanup (remove rdflib bcond, adjust BuildRequires to utilize pkgconfig () etc.
- now carla's own GUI uses Qt5 instead of Qt4
* Sat Aug  4 2018 opensuse-packaging@opensuse.org
- Update to version 1.9.9+git20180721.c03571a9:
  * Forgot to bump version in a script
  * Bump version to beta7
  * Update submodule
  * Don't show option regarding qutting carla in carla plugin settings
  * Don't show quit confirmation dialog when running as plugin
  * More aggressive hacks around linuxsampler
  * Fix spelling
  * Fix SharedResourcePointer includes
  * Allow CarlaMutex to be constructed on the heap
  * Minor compiler warning fix
  + Add confirmation dialog for quitting Carla
  + Add confirmation dialog for "Remove All" and "New File" actions
  + Add internal MIDI Channel A/B plugin
  + Add semitones parameter to internal midi-transpose plugin
  + Implement move up/down plugins in rack (right-click menu)
  + Implement LV2 UI port notifications to feedback messages to UI
  + Implement more libjack stubs, Catia now loads inside Carla :)
  + Transport controls are now considered stable and always enabled, no longer in experimental settings
  + Disable ableton-link and audio kits search UI elements if not built/enabled
  + Do not capture logs if running in nogui mode
  + Do not use or check for kVstParameterUsesIntegerMinMax VST property
  + Do not lockup on close in case audio driver stops working
  + Export LV2 window is now a simple combo-box, making it more usable
  + Save plugin author name in exported LV2 plugin
  + Increase polling rate for non-gui mode (30 Hz), fixes slow OSC handling
  + Fix mouse position offset of Carla-embed mouse events
  + Fix processing of internal plugins with multi MIDI inputs
  + Fix crash when closing a session containing bridges with Ctrl+C
  + Fix patchbay/graph to work with variable buffer sizes
  + Fix some issues regarding integer parameter control
  + Fix controlling logarithmic parameters with MIDI CC
  + Fix "MIDI CC 0x01" not selectable in some systems
  + Fix loading of VST plugin parameters and LV2 state for plugin bridges
  + Fix carla-single usage under ladish
  + Fix file dialog filter of the internal MIDI file plugin
* Wed Feb 28 2018 dimstar@opensuse.org
- Drop liblinuxsampler-devel BuildRequires: linuxsamplerate was
  identified to have an exception clause on their 'gpl license'
  that makes it non-free (non-commercial exception).
* Mon Nov 20 2017 edogawa@aon.at
- added carla.libjack-soversion.patch (removes soversion from private libjack.so.0)
- removed unneeded explicit BuildRequires: jack-devel,
* Wed Nov 15 2017 edogawa@aon.at
- Update to version 1.9.7+git20171111.5b97ec1e
  * removed carla-buildcompare.patch, not needed anymore
  * updated carla-systemlibs.patch so it applies to current source
* Fri Aug 11 2017 edogawa@aon.at
- remove carla-gcc7.patch - being a failed attempt to fix 32bit compilation
* Thu Aug 10 2017 olaf@aepfle.de
- Wipe __DATE__/__TIME with carla-buildcompare.patch
- Fix build with carla-gcc7.patch
- Use system flac/vorbis/ogg with carla-systemlibs.patch
- ExclusiveArch x86_64 until i386 is fixed
* Fri Jul  7 2017 9@cirno.systems
- Add missing runtime dependency on PyQt4
* Fri Jun 16 2017 olaf@aepfle.de
- Remove override of pyuic4
* Tue Mar 28 2017 olaf@aepfle.de
- ExclusiveArch Intel
* Fri Feb 24 2017 opensuse-packaging@opensuse.org
- Update to version 1.9.7+git20170124.9ff1711b:
  * Remove (unused) usage of pyqtWrapperType
* Sun Feb  5 2017 jengelh@inai.de
- Trim irrelevant parts from description
* Tue Jan 17 2017 olaf@aepfle.de
- change mode from localonly to disabled in _service
- fix build on nonx86
* Mon Aug 15 2016 olaf@aepfle.de
- Update to 1.9.6+git20160801.e07f144
  + Fix build with gcc6
* Mon Mar  7 2016 edogawa@aon.at
- Update to version 1.9.6+git20160305.f8933f9:
  + Update zynaddsubfx
  + Add carla-patchbay-vst 16 channel variant
  + Give a name to the patchbay internal ports; Cleanup
  + Add ZebraHZ to the list of u-he workarounds
  + Try to avoid denormals for plugin bridges
  + Fix build
  + Update juce
  + Fix for nasty&weird mingw compiler error
  + Update zynaddsubfx Fixes #368
  + Remove mverb as internal plugin Having GPLv3 as license makes carla itself GPLv3. Let's keep Carla at GPLv2+ please :) (a single simple plugin is not worth the "upgrade")
  + Update DPF based modules
  + Update DPF based plugins (only minor misc changes)
* Sat Jan 30 2016 edogawa@aon.at
- some more spec file cleanup
  + removed unneeded buildreqs and reordered the remaining ones for readability
* Sat Jan 30 2016 rpm@fthiessen.de
- Added bcond (conditional build) for python3-qt4/5 and rdflib
  + Fixes build with openSUSE 13.1 and openSUSE Leap 42.1
- General spec file cleanup
- Update to version 1.9.6+git20160124.544f0fc:
  + Implement discovery for ':all' used in last commit
  + Some minor changes needed for bridged AU plugins
  + Don't use unneeded functions in discovery, fixes windows build
  + Ignore uniqueIds for LV2 plugins
  + Use plugin audio port names in bridge mode Fixes #344
  + Avoid calling jack1's bad set_thread_init_callback Fixes #337
  + Increase the maximum allowed per-atom size
  + Don't write atom to ringbuffer after it fails the initial data
  + Find plugin binary when saved filename doesn't exist
* Tue Jan 12 2016 edogawa@aon.at
- updated to version 1.9.6.git.2016.01.02
* Tue Mar 31 2015 edogawa@aon.at
- updated to 2.0-beta4
* Sat Jan 10 2015 edogawa@aon.at
- initial package (version 2.0-beta3)
